Documentation
¶
Index ¶
- func BucketList(p string) []string
- func CloseInstance()
- func DateBucket(p string, d string) storm.Node
- func Find(field string, value interface{}, to interface{}) error
- func GetAll(d interface{}) error
- func GetAllByIndex(field string, d interface{}) error
- func InitStatus()
- func One(field string, value interface{}, to interface{}) error
- type DataS
- type Database
- type GroupS
- type StatusS
- type UserS
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BucketList ¶
There is no way with storm to get a list of all buckets. This uses a direct Bolt view to get the list
func CloseInstance ¶
func CloseInstance()
func GetAllByIndex ¶
func InitStatus ¶
func InitStatus()
Types ¶
type Database ¶
func GetInstance ¶
func GetInstance() *Database
type GroupS ¶
type StatusS ¶
Click to show internal directories.
Click to hide internal directories.